@@ -1,12 +1,12 @@
 import argparse
 import matplotlib.pyplot as plt
 from matplotlib import cm
-from matplotlib.image import NonUniformImage
 import numpy as np
 import time
 import hamplots as hp
 import os
 import datetime
+import subprocess
 
 def my_pcolor(ax, fig, rowheads, colheads, cells):
     nx=len(colheads)
@@ -25,62 +25,79 @@ myBands = "40m, 20m, 15m, 10m, 2m"
 myModes = "FT8, FT4"
     
 def start_rx(runsecs):
+    print("Start Rx")
     rx_listener = hp.pskr_listener(mySquares, modes = myModes, bands = myBands, TxRx = "Rx", to_file = "Rx_decodes.csv")
     rx_listener.loop_for_time(runsecs);
+    print("Disconnect Rx")
     rx_listener.disconnect();
 
 def start_tx(runsecs):
+    print("Start Tx")
     tx_listener = hp.pskr_listener(mySquares, modes = myModes, bands = myBands, TxRx = "Tx", to_file = "Tx_decodes.csv")
     tx_listener.loop_for_time(runsecs);
+    print("Disconnect Tx")
     tx_listener.disconnect();
 
-def do_plots():
+def do_plots(timewin_start_offset_secs):
     for RxTx in ["Rx","Tx"]:
         decodes = hp.read_csv(f"{RxTx}_decodes.csv")
         if(not decodes):
             continue
 
-        
-        timewin_start = time.time() - 15*60
+        timewin_start = time.time() - timewin_start_offset_secs
         for band in myBands.split(", "):
             for mode in myModes.split(", "):
                 print(f"Rx_{band}_{mode}")
 
                 remote_calls, homecall_reports = hp.build_connectivity_info(decodes, start_epoch = timewin_start, bands=band, modes=mode)
                 remote_calls = hp.cover_home_calls(remote_calls, homecall_reports)
+
+                # plot setup
+                timestr = datetime.datetime.now().strftime("%d/%m/%Y %H:%M UTC")
+                fig, axs = plt.subplots()
+                remote_action = "Transmitting" if RxTx == "Rx" else "Receiving"
+                home_entities = "Receivers'" if RxTx == "Rx" else "Transmitters'"
+                axs.set_ylabel(f"{remote_action} callsign")
+                plt.suptitle(f"Activity over last {timewin_start_offset_secs/60:.0f} minutes\n to/from {mySquares}")
+                axs.set_title(f"{home_entities} SNR on {band} {mode}, to {timestr}")
                 
                 if remote_calls:
-                    if(len(remote_calls) < 3):
-                        continue
                     rowheads, colheads, cells = hp.tabulate_reports(remote_calls, homecall_reports)
-
+                    print(f" ... analysing {len(rowheads)} by {len(colheads)}")
+                    
                     # build DataFrame
                     import pandas as pd
                     cells = pd.DataFrame(cells, index=rowheads, columns=colheads)
                     
-                    # sort
+                    # sort criteria
                     nRemotes_in_row = cells.replace(-30, np.nan).count(axis=1)
                     nRemotes_in_column = cells.replace(-30, np.nan).count(axis=0)
                    # mean_snr_in_column = cells.mean(axis=0)
+
+                    # do sort
                     cells = cells.loc[nRemotes_in_row.sort_values(ascending=True).index,
                                     nRemotes_in_column.sort_values(ascending=False).index]
                     cells = cells.replace(-30, -70)
-
-                    # plot
-                    timestr = datetime.datetime.now().strftime("%d/%m/%Y %H:%M UTC")
-                    fig, axs = plt.subplots()
-                    remote_action = "Transmitting" if RxTx == "Rx" else "Receiving"
-                    home_entities = "receivers" if RxTx == "Rx" else "transmitters"
-                    axs.set_ylabel(f"{remote_action} callsign")
-                    axs.set_title(f"SNR Heatmap for home {home_entities} on {band} {mode}\n{timestr}")
-                    
+                
                     my_pcolor(axs,fig, rowheads, colheads, cells)
-                    plt.tight_layout()
-                 
-                    if not os.path.exists("plots"):
-                        os.makedirs("plots")
-                    plt.savefig(f"plots/{RxTx}_{band}_{mode}.png")
-                    plt.close()
+
+                plt.tight_layout()         
+                if not os.path.exists("plots"):
+                    os.makedirs("plots")
+                plt.savefig(f"plots/{RxTx}_{band}_{mode}.png")
+                plt.close()
+
+def do_periodic_uploads(uploadsecs):
+    with open("upload.bat", "w") as f:
+        print("Writing upload.bat")
+        f.write("git add -f ./plots/*.png\n")
+        f.write("git commit -m 'upload local data'\n")
+        f.write("git pull\n")
+        f.write("git clean -f\n")
+        f.write("git push -f\n")
+    while (True):
+        subprocess.Popen(["upload.bat"], creationflags=subprocess.CREATE_NO_WINDOW)
+        time.sleep(uploadsecs)
 
 
 def get_args_and_run():
@@ -91,8 +108,10 @@ def get_args_and_run():
         __version__ = ""
     print(f"Hamplots {__version__} by Dr Alan Robinson")
     parser = argparse.ArgumentParser()
-    parser.add_argument('action', type=str)
-    parser.add_argument('--runsecs', type=str, default = "30")
+    parser.add_argument('action', type=str, help = "start_rx|start_tx|do_plots|start_all|--runsecs nsecs|--plotsecs nsecs|--uploadsecs nsecs")
+    parser.add_argument('--runsecs', type=str, default = "30", help = "Run mqtt listener for runsecs seconds")
+    parser.add_argument('--plotsecs', type=str, default = "600", help = "Create plots covering now to now minus plotsecs seconds")
+    parser.add_argument('--uploadsecs', type=str, default = "600", help = "Upload to github every uploadsecs seconds")
     args = parser.parse_args()
     print(f"args.action = .{args.action}.")
     if(args.action == "start_rx"):
@@ -100,15 +119,24 @@ def get_args_and_run():
     if(args.action == "start_tx"):
         start_tx(int(args.runsecs))
     if(args.action == "do_plots"):
-        do_plots()
-        
+        do_plots(int(args.plotsecs))
+    if(args.action == "do_all"):
+        start_rx(int(args.runsecs))
+        start_tx(int(args.runsecs))
+        do_plots(int(args.plotsecs))
+    if(args.action == "start_uploader"):
+        do_periodic_uploads(int(args.uploadsecs))
+
+    if(args.action == "start_all"):
+        print("Starting Rx listener")
+        subprocess.Popen(["hamplots", "start_rx", "--runsecs", "1000000"], creationflags=subprocess.CREATE_NO_WINDOW)
+        print("Starting Tx listener")
+        subprocess.Popen(["hamplots", "start_tx", "--runsecs", "1000000"], creationflags=subprocess.CREATE_NO_WINDOW)
+        uploadsecs = int(args.uploadsecs)
+        print(f"Starting Uploader with period {uploadsecs}")
+        subprocess.Popen(["hamplots", "start_uploader", "--uploadsecs", str(uploadsecs)], creationflags=subprocess.CREATE_NO_WINDOW)
+
 
-# if run from an IDE:
-if __name__ == "__main__":
-    print("Edit the lines below this to run what you need")
-    start_tx(60)
-    start_rx(60)
-    do_plots()
 
 
 
